;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "eldev" "20250314.2105"
  "Elisp development tool."
  '((emacs "24.4"))
  :url "https://github.com/emacs-eldev/eldev"
  :commit "87373ddace0c4b2267d8f45ebd20e4b0eb27f821"
  :revdesc "87373ddace0c"
  :keywords '("maint" "tools")
  :authors '(("Paul Pogonyshev" . "pogonyshev@gmail.com"))
  :maintainers '(("Paul Pogonyshev" . "pogonyshev@gmail.com")))
